==> rezdy_api_for_suppliers_client-1.0.0.tar.gz: rezdy_api_for_suppliers_client-1.0.0/rezdy_api_for_suppliers_client/api/extra/update_extra_by_id.py <==
from typing import Any, Dict

import httpx

from ...client import Client
from ...models.extra_request import ExtraRequest
from ...types import Response


def _get_kwargs(
    extra_id: int,
    *,
    client: Client,
    json_body: ExtraRequest,
) -> Dict[str, Any]:
    url = "{}/extra/{extraId}".format(client.base_url, extraId=extra_id)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    json_json_body = json_body.to_dict()

    return {
        "method": "put",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _build_response(*, response: httpx.Response) -> Response[Any]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=None,
    )


def sync_detailed(
    extra_id: int,
    *,
    client: Client,
    json_body: ExtraRequest,
) -> Response[Any]:
    """Update extra

     Updates an extra. The extra ID can change when updating it, since there are business rules to
    protect the Order and Product consistency.

    Args:
        extra_id (int):
        json_body (ExtraRequest): Partial optional service or item that can be purchased when
            booking a specific product

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        extra_id=extra_id,
        client=client,
        json_body=json_body,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


async def asyncio_detailed(
    extra_id: int,
    *,
    client: Client,
    json_body: ExtraRequest,
) -> Response[Any]:
    """Update extra

     Updates an extra. The extra ID can change when updating it, since there are business rules to
    protect the Order and Product consistency.

    Args:
        extra_id (int):
        json_body (ExtraRequest): Partial optional service or item that can be purchased when
            booking a specific product

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        extra_id=extra_id,
        client=client,
        json_body=json_body,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(response=response)

==> rezdy_api_for_suppliers_client-1.0.1.tar.gz: rezdy_api_for_suppliers_client-1.0.1/rezdy_api_for_suppliers_client/api/extra/update_extra_by_id.py <==
from typing import Any, Dict, Optional

import httpx

from ...client import Client
from ...models.extra_request import ExtraRequest
from ...models.response_extra import ResponseExtra
from ...types import Response


def _get_kwargs(
    extra_id: int,
    *,
    client: Client,
    json_body: ExtraRequest,
) -> Dict[str, Any]:
    url = "{}/extra/{extraId}".format(client.base_url, extraId=extra_id)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    json_json_body = json_body.to_dict()

    return {
        "method": "put",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _parse_response(*, response: httpx.Response) -> Optional[ResponseExtra]:
    if response.status_code == 200:
        response_200 = ResponseExtra.from_dict(response.json())

        return response_200
    return None


def _build_response(*, response: httpx.Response) -> Response[ResponseExtra]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    extra_id: int,
    *,
    client: Client,
    json_body: ExtraRequest,
) -> Response[ResponseExtra]:
    """Update extra

     Updates an extra. The extra ID can change when updating it, since there are business rules to
    protect the Order and Product consistency.

    Args:
        extra_id (int):
        json_body (ExtraRequest): Partial optional service or item that can be purchased when
            booking a specific product

    Returns:
        Response[ResponseExtra]
    """

    kwargs = _get_kwargs(
        extra_id=extra_id,
        client=client,
        json_body=json_body,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    extra_id: int,
    *,
    client: Client,
    json_body: ExtraRequest,
) -> Optional[ResponseExtra]:
    """Update extra

     Updates an extra. The extra ID can change when updating it, since there are business rules to
    protect the Order and Product consistency.

    Args:
        extra_id (int):
        json_body (ExtraRequest): Partial optional service or item that can be purchased when
            booking a specific product

    Returns:
        Response[ResponseExtra]
    """

    return sync_detailed(
        extra_id=extra_id,
        client=client,
        json_body=json_body,
    ).parsed


async def asyncio_detailed(
    extra_id: int,
    *,
    client: Client,
    json_body: ExtraRequest,
) -> Response[ResponseExtra]:
    """Update extra

     Updates an extra. The extra ID can change when updating it, since there are business rules to
    protect the Order and Product consistency.

    Args:
        extra_id (int):
        json_body (ExtraRequest): Partial optional service or item that can be purchased when
            booking a specific product

    Returns:
        Response[ResponseExtra]
    """

    kwargs = _get_kwargs(
        extra_id=extra_id,
        client=client,
        json_body=json_body,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(response=response)


async def asyncio(
    extra_id: int,
    *,
    client: Client,
    json_body: ExtraRequest,
) -> Optional[ResponseExtra]:
    """Update extra

     Updates an extra. The extra ID can change when updating it, since there are business rules to
    protect the Order and Product consistency.

    Args:
        extra_id (int):
        json_body (ExtraRequest): Partial optional service or item that can be purchased when
            booking a specific product

    Returns:
        Response[ResponseExtra]
    """

    return (
        await asyncio_detailed(
            extra_id=extra_id,
            client=client,
            json_body=json_body,
        )
    ).parsed
